@@ -24,7 +24,7 @@
 #define MP4V2_PROJECT_repo_rev        493
 #define MP4V2_PROJECT_repo_date       "2012-05-20 15:16:54 -0700 (Sun, 20 May 2012)"
 #define MP4V2_PROJECT_repo_type       "stable"
-#define MP4V2_PROJECT_build           "Fri Dec 11 10:55:00 MST 2015"
+#define MP4V2_PROJECT_build           "Thu May 31 01:24:39 UTC 2018"
 
 /*****************************************************************************/
 
